pub fn parse_update_strategy(value: &str) -> Option<UpdateStrategy>Expand description
Port of parse_submodule_update_strategy (git submodule.c). Returns the
parsed strategy, or None for an unrecognized value (git’s -1).
pub fn parse_update_strategy(value: &str) -> Option<UpdateStrategy>Port of parse_submodule_update_strategy (git submodule.c). Returns the
parsed strategy, or None for an unrecognized value (git’s -1).